==> ppdiffusers-0.16.1.tar.gz: ppdiffusers-0.16.1/tests/others/test_image_processor.py <==
# coding=utf-8
# Copyright 2023 HuggingFace Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import unittest

import numpy as np
import paddle
import PIL

from ppdiffusers.image_processor import VaeImageProcessor


class ImageProcessorTest(unittest.TestCase):
    @property
    def dummy_sample(self):
        batch_size = 1
        num_channels = 3
        height = 8
        width = 8

        sample = paddle.rand((batch_size, num_channels, height, width))

        return sample

    def to_np(self, image):
        if isinstance(image[0], PIL.Image.Image):
            return np.stack([np.array(i) for i in image], axis=0)
        elif isinstance(image, paddle.Tensor):
            return image.transpose([0, 2, 3, 1]).cpu().numpy()
        return image

    def test_vae_image_processor_pd(self):
        image_processor = VaeImageProcessor(do_resize=False, do_normalize=False)

        input_pd = self.dummy_sample
        input_np = self.to_np(input_pd)

        for output_type in ["pd", "np", "pil"]:
            out = image_processor.postprocess(
                image_processor.preprocess(input_pd),
                output_type=output_type,
            )
            out_np = self.to_np(out)
            in_np = (input_np * 255).round() if output_type == "pil" else input_np
            assert (
                np.abs(in_np - out_np).max() < 1e-6
            ), f"decoded output does not match input for output_type {output_type}"

    def test_vae_image_processor_np(self):
        image_processor = VaeImageProcessor(do_resize=False, do_normalize=False)
        input_np = self.dummy_sample.transpose([0, 2, 3, 1]).cpu().numpy()

        for output_type in ["pd", "np", "pil"]:
            out = image_processor.postprocess(image_processor.preprocess(input_np), output_type=output_type)

            out_np = self.to_np(out)
            in_np = (input_np * 255).round() if output_type == "pil" else input_np
            assert (
                np.abs(in_np - out_np).max() < 1e-6
            ), f"decoded output does not match input for output_type {output_type}"

    def test_vae_image_processor_pil(self):
        image_processor = VaeImageProcessor(do_resize=False, do_normalize=False)

        input_np = self.dummy_sample.transpose([0, 2, 3, 1]).cpu().numpy()
        input_pil = image_processor.numpy_to_pil(input_np)

        for output_type in ["pd", "np", "pil"]:
            out = image_processor.postprocess(image_processor.preprocess(input_pil), output_type=output_type)
            for i, o in zip(input_pil, out):
                in_np = np.array(i)
                out_np = self.to_np(out) if output_type == "pil" else (self.to_np(out) * 255).round()
                assert (
                    np.abs(in_np - out_np).max() < 1e-6
                ), f"decoded output does not match input for output_type {output_type}"

    def test_preprocess_input_3d(self):
        image_processor = VaeImageProcessor(do_resize=False, do_normalize=False)

        input_pd_4d = self.dummy_sample
        input_pd_3d = input_pd_4d.squeeze(0)

        out_pt_4d = image_processor.postprocess(
            image_processor.preprocess(input_pd_4d),
            output_type="np",
        )
        out_pt_3d = image_processor.postprocess(
            image_processor.preprocess(input_pd_3d),
            output_type="np",
        )

        input_np_4d = self.to_np(self.dummy_sample)
        input_np_3d = input_np_4d.squeeze(0)

        out_np_4d = image_processor.postprocess(
            image_processor.preprocess(input_np_4d),
            output_type="np",
        )
        out_np_3d = image_processor.postprocess(
            image_processor.preprocess(input_np_3d),
            output_type="np",
        )

        assert np.abs(out_pt_4d - out_pt_3d).max() < 1e-6
        assert np.abs(out_np_4d - out_np_3d).max() < 1e-6

    def test_preprocess_input_list(self):
        image_processor = VaeImageProcessor(do_resize=False, do_normalize=False)

        input_pd_4d = self.dummy_sample
        input_pd_list = list(input_pd_4d)

        out_pt_4d = image_processor.postprocess(
            image_processor.preprocess(input_pd_4d),
            output_type="np",
        )

        out_pt_list = image_processor.postprocess(
            image_processor.preprocess(input_pd_list),
            output_type="np",
        )

        input_np_4d = self.to_np(self.dummy_sample)
        list(input_np_4d)

        out_np_4d = image_processor.postprocess(
            image_processor.preprocess(input_pd_4d),
            output_type="np",
        )

        out_np_list = image_processor.postprocess(
            image_processor.preprocess(input_pd_list),
            output_type="np",
        )

        assert np.abs(out_pt_4d - out_pt_list).max() < 1e-6
        assert np.abs(out_np_4d - out_np_list).max() < 1e-6

==> ppdiffusers-0.16.3.tar.gz: ppdiffusers-0.16.3/tests/others/test_image_processor.py <==
# coding=utf-8
# Copyright 2023 HuggingFace Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import unittest

import numpy as np
import paddle
import PIL

from ppdiffusers.image_processor import VaeImageProcessor


class ImageProcessorTest(unittest.TestCase):
    @property
    def dummy_sample(self):
        batch_size = 1
        num_channels = 3
        height = 8
        width = 8

        sample = paddle.rand((batch_size, num_channels, height, width))

        return sample

    def to_np(self, image):
        if isinstance(image[0], PIL.Image.Image):
            return np.stack([np.array(i) for i in image], axis=0)
        elif isinstance(image, paddle.Tensor):
            return image.transpose([0, 2, 3, 1]).cpu().numpy()
        return image

    def test_vae_image_processor_pd(self):
        image_processor = VaeImageProcessor(do_resize=False, do_normalize=False)

        input_pd = self.dummy_sample
        input_np = self.to_np(input_pd)

        for output_type in ["pd", "np", "pil"]:
            out = image_processor.postprocess(
                image_processor.preprocess(input_pd),
                output_type=output_type, )
            out_np = self.to_np(out)
            in_np = (input_np *
                     255).round() if output_type == "pil" else input_np
            assert (
                np.abs(in_np - out_np).max() < 1e-6
            ), f"decoded output does not match input for output_type {output_type}"

    def test_vae_image_processor_np(self):
        image_processor = VaeImageProcessor(do_resize=False, do_normalize=False)
        input_np = self.dummy_sample.transpose([0, 2, 3, 1]).cpu().numpy()

        for output_type in ["pd", "np", "pil"]:
            out = image_processor.postprocess(
                image_processor.preprocess(input_np), output_type=output_type)

            out_np = self.to_np(out)
            in_np = (input_np *
                     255).round() if output_type == "pil" else input_np
            assert (
                np.abs(in_np - out_np).max() < 1e-6
            ), f"decoded output does not match input for output_type {output_type}"

    def test_vae_image_processor_pil(self):
        image_processor = VaeImageProcessor(do_resize=False, do_normalize=False)

        input_np = self.dummy_sample.transpose([0, 2, 3, 1]).cpu().numpy()
        input_pil = image_processor.numpy_to_pil(input_np)

        for output_type in ["pd", "np", "pil"]:
            out = image_processor.postprocess(
                image_processor.preprocess(input_pil), output_type=output_type)
            for i, o in zip(input_pil, out):
                in_np = np.array(i)
                out_np = self.to_np(out) if output_type == "pil" else (
                    self.to_np(out) * 255).round()
                assert (
                    np.abs(in_np - out_np).max() < 1e-6
                ), f"decoded output does not match input for output_type {output_type}"

    def test_preprocess_input_3d(self):
        image_processor = VaeImageProcessor(do_resize=False, do_normalize=False)

        input_pd_4d = self.dummy_sample
        input_pd_3d = input_pd_4d.squeeze(0)

        out_pt_4d = image_processor.postprocess(
            image_processor.preprocess(input_pd_4d),
            output_type="np", )
        out_pt_3d = image_processor.postprocess(
            image_processor.preprocess(input_pd_3d),
            output_type="np", )

        input_np_4d = self.to_np(self.dummy_sample)
        input_np_3d = input_np_4d.squeeze(0)

        out_np_4d = image_processor.postprocess(
            image_processor.preprocess(input_np_4d),
            output_type="np", )
        out_np_3d = image_processor.postprocess(
            image_processor.preprocess(input_np_3d),
            output_type="np", )

        assert np.abs(out_pt_4d - out_pt_3d).max() < 1e-6
        assert np.abs(out_np_4d - out_np_3d).max() < 1e-6

    def test_preprocess_input_list(self):
        image_processor = VaeImageProcessor(do_resize=False, do_normalize=False)

        input_pd_4d = self.dummy_sample
        input_pd_list = list(input_pd_4d)

        out_pt_4d = image_processor.postprocess(
            image_processor.preprocess(input_pd_4d),
            output_type="np", )

        out_pt_list = image_processor.postprocess(
            image_processor.preprocess(input_pd_list),
            output_type="np", )

        input_np_4d = self.to_np(self.dummy_sample)
        list(input_np_4d)

        out_np_4d = image_processor.postprocess(
            image_processor.preprocess(input_pd_4d),
            output_type="np", )

        out_np_list = image_processor.postprocess(
            image_processor.preprocess(input_pd_list),
            output_type="np", )

        assert np.abs(out_pt_4d - out_pt_list).max() < 1e-6
        assert np.abs(out_np_4d - out_np_list).max() < 1e-6
